Small annotation improvements...

[Christophe Saout]
--- diff/drivers/md/dm-crypt.c	2004-01-03 12:14:36.000000000 +0000
+++ source/drivers/md/dm-crypt.c	2004-01-03 12:14:42.000000000 +0000
@@ -101,12 +101,6 @@
 	return 0;
 }
 
-/*
- * Encrypt / decrypt a single sector, source and destination buffers
- * are stored in scatterlists. In CBC mode initialise the "previous
- * block" with the sector number (it's not a real chaining because
- * it would not allow to seek on the device...)
- */
 static inline int
 crypt_convert_scatterlist(struct crypt_config *cc, struct scatterlist *out,
                           struct scatterlist *in, unsigned int length,
@@ -150,7 +144,7 @@
 }
 
 /*
- * Encrypt / decrypt data from one bio to another one (may be the same)
+ * Encrypt / decrypt data from one bio to another one (can be the same one)
  */
 static int crypt_convert(struct crypt_config *cc,
                          struct convert_context *ctx)
@@ -224,7 +218,7 @@
 	if (!bio)
 		return NULL;
 
-	/* if the last bio was not complete, continue where that one ends */
+	/* if the last bio was not complete, continue where that one ended */
 	bio->bi_idx = *bio_vec_idx;
 	bio->bi_vcnt = *bio_vec_idx;
 	bio->bi_size = 0;
@@ -240,7 +234,7 @@
 			break;
 
 		/*
-		 * if additional pages cannot be allocated without waiting
+		 * if additional pages cannot be allocated without waiting,
 		 * return a partially allocated bio, the caller will then try
 		 * to allocate additional bios while submitting this partial bio
 		 */
@@ -267,8 +261,8 @@
 	}
 
 	/*
-	 * remember the last bio_vec allocated to be able to correctly
-	 * continue after splitting caused by memory pressure
+	 * Remember the last bio_vec allocated to be able
+	 * to correctly continue after the splitting.
 	 */
 	*bio_vec_idx = bio->bi_vcnt;
 
@@ -294,7 +288,7 @@
 
 /*
  * One of the bios was finished. Check for completion of
- * the whole request and correctly cleanup the buffer.
+ * the whole request and correctly clean up the buffer.
  */
 static void dec_pending(struct crypt_io *io, int error)
 {
@@ -318,8 +312,8 @@
 /*
  * kcryptd:
  *
- * Needed because we can't decrypt when called in an
- * interrupt context, so returning bios from read requests get
+ * Needed because it would be very unwise to do decryption in an
+ * interrupt context, so bios returning from read requests get
  * queued here.
  */
 static spinlock_t _kcryptd_lock = SPIN_LOCK_UNLOCKED;
@@ -588,8 +582,7 @@
 		return 1;
 
 	/*
-	 * successful reads get decrypted by the worker thread
-	 * because we never want to decrypt in an irq context
+	 * successful reads are decrypted by the worker thread
 	 */
 	if ((bio_rw(bio) == READ || bio_rw(bio) == READA)
 	    && bio_flagged(bio, BIO_UPTODATE)) {
@@ -626,7 +619,7 @@
 		crypt_convert_init(cc, &ctx, NULL, bio, sector, 1);
 
 	/*
-	 * The allocated buffers can be smaller then the whole bio,
+	 * The allocated buffers can be smaller than the whole bio,
 	 * so repeat the whole process until all the data can be handled.
 	 */
 	while (remaining) {
@@ -654,9 +647,9 @@
 
 		if (!io->first_clone) {
 			/*
-			 * hold a reference to the first clone, because it holds
-			 * the bio_vec array and that needs to be released only
-			 * after all other clones are released
+			 * hold a reference to the first clone, because it
+			 * holds the bio_vec array and that can't be freed
+			 * before all other clones are released
 			 */
 			bio_get(clone);
 			io->first_clone = clone;
